summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/build.c
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/3rdparty/kexisql3/src/build.c
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/build.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/build.c42
1 files changed, 21 insertions, 21 deletions
diff --git a/kexi/3rdparty/kexisql3/src/build.c b/kexi/3rdparty/kexisql3/src/build.c
index 429213da..02faa0fe 100644
--- a/kexi/3rdparty/kexisql3/src/build.c
+++ b/kexi/3rdparty/kexisql3/src/build.c
@@ -67,19 +67,19 @@ void sqlite3FinishCoding(Parse *pParse){
if( v ){
sqlite3VdbeAddOp(v, OP_Halt, 0, 0);
/* The cookie mask contains one bit for each database file open.
** (Bit 0 is for main, bit 1 is for temp, and so forth.) Bits are
** set for each database that is used. Generate code to start a
** transaction on each used database and to verify the schema cookie
** on each used database.
*/
if( pParse->cookieGoto>0 ){
- u32 mask;
+ u32 tqmask;
int iDb;
sqlite3VdbeJumpHere(v, pParse->cookieGoto-1);
- for(iDb=0, mask=1; iDb<db->nDb; mask<<=1, iDb++){
- if( (mask & pParse->cookieMask)==0 ) continue;
- sqlite3VdbeAddOp(v, OP_Transaction, iDb, (mask & pParse->writeMask)!=0);
+ for(iDb=0, tqmask=1; iDb<db->nDb; tqmask<<=1, iDb++){
+ if( (tqmask & pParse->cookieMask)==0 ) continue;
+ sqlite3VdbeAddOp(v, OP_Transaction, iDb, (tqmask & pParse->writeMask)!=0);
sqlite3VdbeAddOp(v, OP_VerifyCookie, iDb, pParse->cookieValue[iDb]);
}
sqlite3VdbeAddOp(v, OP_Goto, 0, pParse->cookieGoto);
@@ -746,7 +746,7 @@ void sqlite3StartTable(
/* Begin generating the code that will insert the table record into
** the SQLITE_MASTER table. Note in particular that we must go ahead
** and allocate the record number for the table entry now. Before any
** PRIMARY KEY or UNIQUE keywords are parsed. Those keywords will cause
** indices to be created and the table record must come before the
** indices. Hence, the record number for the table must be allocated
** now.
@@ -879,7 +879,7 @@ void sqlite3AddNotNull(Parse *pParse, int onError){
**
** This routine does a case-independent search of zType for the
** substrings in the following table. If one of the substrings is
-** found, the corresponding affinity is returned. If zType contains
+** found, the corresponding affinity is returned. If zType tqcontains
** more than one of the substrings, entries toward the top of
** the table take priority. For example, if zType is 'BLOBINT',
** SQLITE_AFF_INTEGER is returned.
@@ -2011,7 +2011,7 @@ static void sqlite3RefillIndex(Parse *pParse, Index *pIndex, int memRootPage){
** Create a new index for an SQL table. pName1.pName2 is the name of the index
** and pTblList is the name of the table that is to be indexed. Both will
** be NULL for a primary key or an index that is created to satisfy a
** UNIQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
** as the table to be indexed. pParse->pNewTable is a table that is
** currently being constructed by a CREATE TABLE statement.
**
@@ -2104,7 +2104,7 @@ void sqlite3CreateIndex(
** index, then we will continue to process this index.
**
** If pName==0 it means that we are
** dealing with a primary key or UNIQUE constraint. We have to invent our
** own name.
*/
if( pName ){
@@ -2211,12 +2211,12 @@ void sqlite3CreateIndex(
if( pTab==pParse->pNewTable ){
/* This routine has been called to create an automatic index as a
** result of a PRIMARY KEY or UNIQUE clause on a column definition, or
** a PRIMARY KEY or UNIQUE clause following the column definitions.
** i.e. one of:
**
** CREATE TABLE t(x PRIMARY KEY, y);
- ** CREATE TABLE t(x, y, UNIQUE(x, y));
+ ** CREATE TABLE t(x, y, UNITQUE(x, y));
**
** Either way, check to see if the table already has such an index. If
** so, don't bother creating this one. This only applies to
@@ -2285,7 +2285,7 @@ void sqlite3CreateIndex(
** we don't want to recreate it.
**
** If pTblName==0 it means this index is generated as a primary key
** or UNIQUE constraint of a CREATE TABLE statement. Since the table
** has just been created, it contains no data and the index initialization
** step can be skipped.
*/
@@ -2309,11 +2309,11 @@ void sqlite3CreateIndex(
if( pStart && pEnd ){
/* A named index with an explicit CREATE INDEX statement */
zStmt = sqlite3MPrintf("CREATE%s INDEX %.*s",
- onError==OE_None ? "" : " UNIQUE",
+ onError==OE_None ? "" : " UNITQUE",
pEnd->z - pName->z + 1,
pName->z);
}else{
- /* An automatic index created by a PRIMARY KEY or UNIQUE constraint */
+ /* An automatic index created by a PRIMARY KEY or UNITQUE constraint */
/* zStmt = sqlite3MPrintf(""); */
zStmt = 0;
}
@@ -2331,7 +2331,7 @@ void sqlite3CreateIndex(
sqliteFree(zStmt);
/* Fill the index with data and reparse the schema. Code an OP_Expire
- ** to invalidate all pre-compiled statements.
+ ** to tqinvalidate all pre-compiled statements.
*/
if( pTblName ){
sqlite3RefillIndex(pParse, pIndex, iMem);
@@ -2428,7 +2428,7 @@ void sqlite3DropIndex(Parse *pParse, SrcList *pName){
goto exit_drop_index;
}
if( pIndex->autoIndex ){
- sqlite3ErrorMsg(pParse, "index associated with UNIQUE "
+ sqlite3ErrorMsg(pParse, "index associated with UNITQUE "
"or PRIMARY KEY constraint cannot be dropped", 0);
goto exit_drop_index;
}
@@ -2766,7 +2766,7 @@ static int sqlite3OpenTempDatabase(Parse *pParse){
void sqlite3CodeVerifySchema(Parse *pParse, int iDb){
sqlite3 *db;
Vdbe *v;
- int mask;
+ int tqmask;
v = sqlite3GetVdbe(pParse);
if( v==0 ) return; /* This only happens if there was a prior error */
@@ -2778,9 +2778,9 @@ void sqlite3CodeVerifySchema(Parse *pParse, int iDb){
assert( iDb<db->nDb );
assert( db->aDb[iDb].pBt!=0 || iDb==1 );
assert( iDb<32 );
- mask = 1<<iDb;
- if( (pParse->cookieMask & mask)==0 ){
- pParse->cookieMask |= mask;
+ tqmask = 1<<iDb;
+ if( (pParse->cookieMask & tqmask)==0 ){
+ pParse->cookieMask |= tqmask;
pParse->cookieValue[iDb] = db->aDb[iDb].schema_cookie;
if( !OMIT_TEMPDB && iDb==1 ){
sqlite3OpenTempDatabase(pParse);
@@ -67,19 +67,19 @@ void sqlite3FinishCoding(Parse *pParse){
if( v ){
sqlite3VdbeAddOp(v, OP_Halt, 0, 0);
- /* The cookie mask contains one bit for each database file open.
+ /* The cookie tqmask contains one bit for each database file open.
** (Bit 0 is for main, bit 1 is for temp, and so forth.) Bits are
** set for each database that is used. Generate code to start a
@@ -746,7 +746,7 @@ void sqlite3StartTable(
** the SQLITE_MASTER table. Note in particular that we must go ahead
** and allocate the record number for the table entry now. Before any
- ** PRIMARY KEY or UNIQUE keywords are parsed. Those keywords will cause
+ ** PRIMARY KEY or UNITQUE keywords are parsed. Those keywords will cause
** indices to be created and the table record must come before the
** indices. Hence, the record number for the table must be allocated
@@ -2011,7 +2011,7 @@ static void sqlite3RefillIndex(Parse *pParse, Index *pIndex, int memRootPage){
** and pTblList is the name of the table that is to be indexed. Both will
** be NULL for a primary key or an index that is created to satisfy a
-** UNIQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
+** UNITQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
** as the table to be indexed. pParse->pNewTable is a table that is
** currently being constructed by a CREATE TABLE statement.
@@ -2104,7 +2104,7 @@ void sqlite3CreateIndex(
**
** If pName==0 it means that we are
- ** dealing with a primary key or UNIQUE constraint. We have to invent our
+ ** dealing with a primary key or UNITQUE constraint. We have to invent our
** own name.
*/
@@ -2211,12 +2211,12 @@ void sqlite3CreateIndex(
if( pTab==pParse->pNewTable ){
/* This routine has been called to create an automatic index as a
- ** result of a PRIMARY KEY or UNIQUE clause on a column definition, or
- ** a PRIMARY KEY or UNIQUE clause following the column definitions.
+ ** result of a PRIMARY KEY or UNITQUE clause on a column definition, or
+ ** a PRIMARY KEY or UNITQUE clause following the column definitions.
** i.e. one of:
**
@@ -2285,7 +2285,7 @@ void sqlite3CreateIndex(
**
** If pTblName==0 it means this index is generated as a primary key
- ** or UNIQUE constraint of a CREATE TABLE statement. Since the table
+ ** or UNITQUE constraint of a CREATE TABLE statement. Since the table
** has just been created, it contains no data and the index initialization
** step can be skipped.